==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/DrawingPreferences/GridSettings/ts/GridSettings_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>Grid</name>
    <message>
        <source>View 1</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Zobacz 1</translation>
    </message>
    <message>
        <source>Display Grid</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Wyświetlanie siatki</translation>
    </message>
    <message>
        <source>Isometric Grid</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Siatka izometryczna</translation>
    </message>
    <message>
        <source>Grid Spacing</source>
        <translatorcomment>--google--
Minimalne odstępy siatki:
Minimalne odstępy siatki
Minimalny odstęp siatki (piksele):</translatorcomment>
        <translation type="obsolete">Odstępy siatki</translation>
    </message>
    <message>
        <source>Y:</source>
        <translatorcomment>--ignored case--
--file: qcadguiqt_pl.ts--
Mnożnik Y:
Mnożnik &amp;Y:</translatorcomment>
        <translation type="obsolete">y:</translation>
    </message>
    <message>
        <source>X:</source>
        <translatorcomment>--ignored case--
--file: qcadguiqt_pl.ts--
Mnożnik X:
Mnożnik &amp;X:</translatorcomment>
        <translation type="obsolete">x:</translation>
    </message>
    <message>
        <source>Meta Grid Spacing</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Odstępy siatki meta</translation>
    </message>
    <message>
        <source>View 3</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Zobacz 3</translation>
    </message>
    <message>
        <source>View 2</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Zobacz 2</translation>
    </message>
    <message>
        <source>View 4</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Zobacz 4</translation>
    </message>
</context>
<context>
    <name>GridSettings</name>
    <message>
        <location filename="../GridSettings.js" line="+25"/>
        <source>Defaults for New Drawings</source>
        <translatorcomment>--ignored case--
--file: qcadguiqt_pl.ts--
Domyślne dla nowych rysunków</translatorcomment>
        <translation type="unfinished">Domyślne dla nowych rysunków</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+2"/>
        <source>Grid</source>
        <translatorcomment>--exact match--
--file: designer_pl.ts--
&amp;Siatka
Siatka
Pozycjonowanie siatki</translatorcomment>
        <translation type="unfinished">Siatka</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>General</source>
        <translatorcomment>--google--
Ogólne ustawienia aplikacji
[2000-206F] General Punctuation
General Punctuation</translatorcomment>
        <translation type="unfinished">Ogólny</translation>
    </message>
    <message>
        <location line="+84"/>
        <location line="+103"/>
        <location line="+1"/>
        <location line="+22"/>
        <location line="+1"/>
        <source>auto</source>
        <translatorcomment>--exact match--
--file: qtconfig_pl.ts--
&amp;Automatycznie
Automatycznie
Przyciąganie automatyczne</translatorcomment>
        <translation type="unfinished">Automatycznie</translation>
    </message>
</context>
<context>
    <name>scrollArea</name>
    <message>
        <source>View 1</source>
        <translation type="obsolete">Zobacz 1</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+29"/>
        <source>Viewport 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+152"/>
        <location line="+152"/>
        <location line="+152"/>
        <source>Display Grid</source>
        <translation type="unfinished">Wyświetlanie siatki</translation>
    </message>
    <message>
        <location line="-446"/>
        <location line="+152"/>
        <location line="+152"/>
        <location line="+152"/>
        <source>Isometric Grid</source>
        <translation type="unfinished">Siatka izometryczna</translation>
    </message>
    <message>
        <location line="-449"/>
        <location line="+152"/>
        <location line="+152"/>
        <location line="+152"/>
        <source>Grid Spacing</source>
        <translation type="unfinished">Odstępy siatki</translation>
    </message>
    <message>
        <location line="-450"/>
        <location line="+90"/>
        <location line="+76"/>
        <location line="+89"/>
        <location line="+76"/>
        <location line="+56"/>
        <location line="+116"/>
        <location line="+30"/>
        <source>Y:</source>
        <translation type="unfinished">y:</translation>
    </message>
    <message>
        <location line="-512"/>
        <location line="+76"/>
        <location line="+55"/>
        <location line="+63"/>
        <location line="+89"/>
        <location line="+90"/>
        <location line="+62"/>
        <location line="+63"/>
        <source>X:</source>
        <translation type="unfinished">x:</translation>
    </message>
    <message>
        <location line="-462"/>
        <location line="+152"/>
        <location line="+152"/>
        <location line="+152"/>
        <source>Meta Grid Spacing</source>
        <translation type="unfinished">Odstępy siatki meta</translation>
    </message>
    <message>
        <location line="-390"/>
        <source>Viewport 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+152"/>
        <source>Viewport 3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+152"/>
        <source>Viewport 4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>View 2</source>
        <translation type="obsolete">Zobacz 2</translation>
    </message>
    <message>
        <source>View 3</source>
        <translation type="obsolete">Zobacz 3</translation>
    </message>
    <message>
        <source>View 4</source>
        <translation type="obsolete">Zobacz 4</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/DrawingPreferences/GridSettings/ts/GridSettings_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Grid</name>
    <message>
        <source>View 1</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Zobacz 1</translation>
    </message>
    <message>
        <source>Display Grid</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Wyświetlanie siatki</translation>
    </message>
    <message>
        <source>Isometric Grid</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Siatka izometryczna</translation>
    </message>
    <message>
        <source>Grid Spacing</source>
        <translatorcomment>--google--
Minimalne odstępy siatki:
Minimalne odstępy siatki
Minimalny odstęp siatki (piksele):</translatorcomment>
        <translation type="obsolete">Odstępy siatki</translation>
    </message>
    <message>
        <source>Y:</source>
        <translatorcomment>--ignored case--
--file: qcadguiqt_pl.ts--
Mnożnik Y:
Mnożnik &amp;Y:</translatorcomment>
        <translation type="obsolete">y:</translation>
    </message>
    <message>
        <source>X:</source>
        <translatorcomment>--ignored case--
--file: qcadguiqt_pl.ts--
Mnożnik X:
Mnożnik &amp;X:</translatorcomment>
        <translation type="obsolete">x:</translation>
    </message>
    <message>
        <source>Meta Grid Spacing</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Odstępy siatki meta</translation>
    </message>
    <message>
        <source>View 3</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Zobacz 3</translation>
    </message>
    <message>
        <source>View 2</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Zobacz 2</translation>
    </message>
    <message>
        <source>View 4</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Zobacz 4</translation>
    </message>
</context>
<context>
    <name>GridSettings</name>
    <message>
        <location filename="../GridSettings.js" line="+27"/>
        <source>Defaults for New Drawings</source>
        <translatorcomment>--ignored case--
--file: qcadguiqt_pl.ts--
Domyślne dla nowych rysunków</translatorcomment>
        <translation>Domyślne dla nowych rysunków</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+2"/>
        <source>Grid</source>
        <translatorcomment>--exact match--
--file: designer_pl.ts--
&amp;Siatka
Siatka
Pozycjonowanie siatki</translatorcomment>
        <translation>Siatka</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>General</source>
        <translatorcomment>--google--
Ogólne ustawienia aplikacji
[2000-206F] General Punctuation
General Punctuation</translatorcomment>
        <translation>Ogólne</translation>
    </message>
    <message>
        <location line="+84"/>
        <location line="+103"/>
        <location line="+1"/>
        <location line="+22"/>
        <location line="+1"/>
        <source>auto</source>
        <translatorcomment>--exact match--
--file: qtconfig_pl.ts--
&amp;Automatycznie
Automatycznie
Przyciąganie automatyczne</translatorcomment>
        <translation>Automatycznie</translation>
    </message>
</context>
<context>
    <name>scrollArea</name>
    <message>
        <source>View 1</source>
        <translation type="obsolete">Zobacz 1</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+29"/>
        <source>Viewport 1</source>
        <translation>Rzutnia 1</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+152"/>
        <location line="+152"/>
        <location line="+152"/>
        <source>Display Grid</source>
        <translation>Wyświetlanie siatki</translation>
    </message>
    <message>
        <location line="-446"/>
        <location line="+152"/>
        <location line="+152"/>
        <location line="+152"/>
        <source>Isometric Grid</source>
        <translation>Siatka izometryczna</translation>
    </message>
    <message>
        <location line="-449"/>
        <location line="+152"/>
        <location line="+152"/>
        <location line="+152"/>
        <source>Grid Spacing</source>
        <translation>Odstępy siatki</translation>
    </message>
    <message>
        <location line="-450"/>
        <location line="+90"/>
        <location line="+76"/>
        <location line="+89"/>
        <location line="+76"/>
        <location line="+56"/>
        <location line="+116"/>
        <location line="+30"/>
        <source>Y:</source>
        <translation>y:</translation>
    </message>
    <message>
        <location line="-512"/>
        <location line="+76"/>
        <location line="+55"/>
        <location line="+63"/>
        <location line="+89"/>
        <location line="+90"/>
        <location line="+62"/>
        <location line="+63"/>
        <source>X:</source>
        <translation>x:</translation>
    </message>
    <message>
        <location line="-462"/>
        <location line="+152"/>
        <location line="+152"/>
        <location line="+152"/>
        <source>Meta Grid Spacing</source>
        <translation>Odstępy siatki meta</translation>
    </message>
    <message>
        <location line="-390"/>
        <source>Viewport 2</source>
        <translation>Rzutnia 2</translation>
    </message>
    <message>
        <location line="+152"/>
        <source>Viewport 3</source>
        <translation>Rzutnia 3</translation>
    </message>
    <message>
        <location line="+152"/>
        <source>Viewport 4</source>
        <translation>Rzutnia 4</translation>
    </message>
    <message>
        <source>View 2</source>
        <translation type="obsolete">Zobacz 2</translation>
    </message>
    <message>
        <source>View 3</source>
        <translation type="obsolete">Zobacz 3</translation>
    </message>
    <message>
        <source>View 4</source>
        <translation type="obsolete">Zobacz 4</translation>
    </message>
</context>
</TS>
